import { NextResponse } from "next/server";
import { z } from "zod";

import { db } from "@/lib/db";

export async function POST(request: Request) {
  const { media } = await request.json();

  const mediaSchema = z
    .object({
      gweetId: z.string().nullable().optional(),
      url: z.string(),
      key: z.string(),
      type: z.string(),
    })
    .strict();

  const zod = mediaSchema.safeParse(media);

  if (!zod.success) {
    return NextResponse.json({ error: zod.error }, { status: 400 });
  }

  try {
    await db.media.create({
      data: {
        ...media,
      },
    });
    return NextResponse.json({ message: "Media created successfully" }, { status: 200 });
  } catch (error: any) {
    return NextResponse.json({ error: error.message }, { status: 500 });
  }
}